'''
backends/__init__.py - this file is part of S3QL (http://s3ql.googlecode.com)

Copyright (C) Nikolaus Rath <Nikolaus@rath.org>

This program can be distributed under the terms of the GNU GPLv3.
'''

from __future__ import division, print_function, absolute_import

__all__ = [ 'common', 'local', 's3', 'gs', 's3c', 'swift', 'rackspace' ]
